@@ -110,6 +110,9 @@ class Project(object):
     def import_excel(self, path):
         excel.open_file(path)
 
+    @property
+    def objects(self) -> Iterator[Object]:
+        return iter(Object)
 
 class Hirarchy(object, metaclass=IterRegistry):
 
@@ -137,11 +140,10 @@ class Hirarchy(object, metaclass=IterRegistry):
         return self._name
 
     @name.setter
-    def name(self, value: str,inherit=True):
+    def name(self, value: str):
         self._name = value
-        if inherit:
-            for child in self.children:
-                child.name = value
+        for child in self.children:
+            child.name = value
         self.changed = True
 
     @property
@@ -566,6 +568,16 @@ class Object(Hirarchy):
     def property_sets(self) -> list[PropertySet]:
         return self._property_sets
 
+    # override name setter because of intheritance
+    @property
+    def name(self) -> str:
+        return self._name
+
+    @name.setter
+    def name(self, value: str):
+        self._name = value
+        self.changed = True
+
     def add_property_set(self, property_set: PropertySet) -> None:
         self._property_sets.append(property_set)
         property_set.object = self
