@@ -4,6 +4,7 @@ import logging
 import os.path
 import shutil
 import tempfile
+import re
 from typing import Iterator
 
 import openpyxl
@@ -20,7 +21,7 @@ ident_attrib_name = "bauteilKlassifikation"
 def split_string(text: str) -> list[str] | None:
     if text is None:
         return []
-    text = text.split(";")
+    text = re.findall(r'[^,;\s]+', text)
     for i, item in enumerate(text):
         if "(" in item:
             item = item.split("(")
@@ -307,13 +308,16 @@ def open_file(path: str) -> None:
 
             for aggregate_block in aggregate_list:
                 if aggregate_block.name != block.name:
-                    child_aggreg = classes.Aggregation(aggregate_block.object)
-                    relationship = constants.AGGREGATION
-                    if aggregate_block in inherit_list:
-                        relationship += constants.INHERITANCE
+                    if aggregate_block.is_predefined_pset:
+                        logging.error(f"[{block.name}] can't aggregate to {aggregate_block.name}")
+                    else:
+                        child_aggreg = classes.Aggregation(aggregate_block.object)
+                        relationship = constants.AGGREGATION
+                        if aggregate_block in inherit_list:
+                            relationship += constants.INHERITANCE
 
-                    aggregation.add_child(child_aggreg, relationship)
-                    link_child_nodes(child_aggreg, aggregate_block)
+                        aggregation.add_child(child_aggreg, relationship)
+                        link_child_nodes(child_aggreg, aggregate_block)
                 else:
                     logging.warning(f"[{aggregation.name}] recursive aggregation")
 
